;; Generated package description from external-completion.el  -*- no-byte-compile: t -*-
(define-package "external-completion" "0.1.0.20230930.220905" "Let external tools control completion style" 'nil :commit "7caa3f5499b1ca4b6d66c1655a4e0d6903755679" :url "https://elpa.gnu.org/packages/external-completion.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("João Távora" . "joaotavora@gmail.com"))
